summaryrefslogtreecommitdiff
path: root/src/cpu/o3/fu_pool.hh
diff options
context:
space:
mode:
Diffstat (limited to 'src/cpu/o3/fu_pool.hh')
-rw-r--r--src/cpu/o3/fu_pool.hh13
1 files changed, 9 insertions, 4 deletions
diff --git a/src/cpu/o3/fu_pool.hh b/src/cpu/o3/fu_pool.hh
index e6bb8cb8e..b6e9c126a 100644
--- a/src/cpu/o3/fu_pool.hh
+++ b/src/cpu/o3/fu_pool.hh
@@ -134,12 +134,17 @@ class FUPool : public SimObject
FUPool(const Params *p);
~FUPool();
+ static constexpr auto NoCapableFU = -2;
+ static constexpr auto NoFreeFU = -1;
/**
- * Gets a FU providing the requested capability. Will mark the unit as busy,
- * but leaves the freeing of the unit up to the IEW stage.
+ * Gets a FU providing the requested capability. Will mark the
+ * unit as busy, but leaves the freeing of the unit up to the IEW
+ * stage.
+ *
* @param capability The capability requested.
* @return Returns -2 if the FU pool does not have the capability, -1 if
* there is no free FU, and the FU's index otherwise.
*/
int getUnit(OpClass capability);
@@ -134,12 +134,17 @@ class FUPool : public SimObject
* @param capability The capability requested.
- * @return Returns -2 if the FU pool does not have the capability, -1 if
- * there is no free FU, and the FU's index otherwise.
+ * @return Returns NoCapableFU if the FU pool does not have the
+ * capability, NoFreeFU if there is no free FU, and the FU's index
+ * otherwise.
*/
int getUnit(OpClass capability);